@@ -11,8 +11,8 @@ the Free Software Foundation, either version 3 of the License, or
 OpenSesame is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
 
+GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with OpenSesame.  If not, see <http://www.gnu.org/licenses/>.
 """
@@ -21,7 +21,7 @@ from libopensesame.py3compat import *
 from distutils.version import StrictVersion
 import sys
 
-__version__ = u'3.2.8'
+__version__ = u'3.3.0'
 strict_version = StrictVersion(__version__)
 # The version without the prerelease (if any): e.g. 3.0.0
 main_version = u'.'.join([str(i) for i in strict_version.version])
@@ -31,7 +31,8 @@ if strict_version.prerelease is None:
 else:
 	deb_version = main_version + u'+%s%d' % strict_version.prerelease
 python_version = u'%d.%d.%d' % sys.version_info[:3]
-codename = u'Kafkaesque Koffka'
+codename = u'Lentiform Loewenfeld'
 channel = u'dev'
 api = StrictVersion(u'2.1')
 platform = sys.platform
+identity = u'OpenSesame {} {}'.format(__version__, codename)
